# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.dashboard_next_nomination_gate import DashboardNextNominationGate  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestDashboardNextNominationGate(unittest.TestCase):
    """DashboardNextNominationGate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DashboardNextNominationGate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DashboardNextNominationGate`
        """
        model = empire_platform_api_public_client.models.dashboard_next_nomination_gate.DashboardNextNominationGate()  # noqa: E501
        if include_optional :
            return DashboardNextNominationGate(
                timescale = 'LONG_TERM', 
                window = empire_platform_api_public_client.models.dashboard_next_nomination_gate_window.DashboardNextNominationGate_window(
                    opens_at = '2022-01-04T00:00Z', 
                    closes_at = '2022-01-04T00:00Z', ), 
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ), 
                status = 'NOT_YET_OPEN', 
                next_action_at = '2022-01-04T00:00Z'
            )
        else :
            return DashboardNextNominationGate(
                timescale = 'LONG_TERM',
                window = empire_platform_api_public_client.models.dashboard_next_nomination_gate_window.DashboardNextNominationGate_window(
                    opens_at = '2022-01-04T00:00Z', 
                    closes_at = '2022-01-04T00:00Z', ),
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ),
                status = 'NOT_YET_OPEN',
                next_action_at = '2022-01-04T00:00Z',
        )
        """

    def testDashboardNextNominationGate(self):
        """Test DashboardNextNominationGate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
