# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class OrganisationDocumentFileType(str, Enum):
    """
    See mapping of MIME Types at `uploadAttachment` endpoint 
    """

    """
    allowed enum values
    """
    IMAGE = 'IMAGE'
    DOCUMENT = 'DOCUMENT'
    TEXT = 'TEXT'
    ARCHIVE = 'ARCHIVE'

    @classmethod
    def from_json(cls, json_str: str) -> OrganisationDocumentFileType:
        """Create an instance of OrganisationDocumentFileType from a JSON string"""
        return OrganisationDocumentFileType(json.loads(json_str))


