# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.day_ahead_auction import DayAheadAuction  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestDayAheadAuction(unittest.TestCase):
    """DayAheadAuction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DayAheadAuction
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DayAheadAuction`
        """
        model = empire_platform_api_public_client.models.day_ahead_auction.DayAheadAuction()  # noqa: E501
        if include_optional :
            return DayAheadAuction(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                name = '2022 May Auction', 
                display_id = 'BDL-NL-GB-E-BASE---220305-01', 
                product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                border_direction = 'GB_NL', 
                status = 'CREATED', 
                processing = True, 
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ), 
                allocation_mtu_size = 'MTU_15_MINS', 
                allocation_resolution = 'RES_1_KW', 
                bidding_configuration = empire_platform_api_public_client.models.auction_bidding_configuration.AuctionBiddingConfiguration(
                    mode = 'OPEN', 
                    pre_bidding_allowed = True, 
                    max_bids_per_participants = 0, 
                    min_bid_price = 1.337, ), 
                process_steps = empire_platform_api_public_client.models.auction_process_steps_absolute.AuctionProcessStepsAbsolute(
                    preliminary_spec_publish = '2022-01-04T00:00Z', 
                    returns_window_close = '2022-01-04T00:00Z', 
                    final_spec_publish = '2022-01-04T00:00Z', 
                    bidding_open = '2022-01-04T00:00Z', 
                    show_bids_for_open_auctions = '2022-01-04T00:00Z', 
                    bidding_close = '2022-01-04T00:00Z', 
                    provisional_results_publish = '2022-01-04T00:00Z', 
                    final_results_publish = '2022-01-04T00:00Z', ), 
                offered_capacity_setup = 'PERCENT_100_ATC', 
                mtus = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_mtu.DayAheadOrIntraDayAuctionMtu(
                        mtu = '2022-01-04T10:00Z', 
                        atc = 56, 
                        preliminary_oc = 56, 
                        un_nominated_capacity = 56, 
                        final_oc = 56, )
                    ]
            )
        else :
            return DayAheadAuction(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                name = '2022 May Auction',
                display_id = 'BDL-NL-GB-E-BASE---220305-01',
                product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                status = 'CREATED',
                processing = True,
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ),
                allocation_mtu_size = 'MTU_15_MINS',
                allocation_resolution = 'RES_1_KW',
                bidding_configuration = empire_platform_api_public_client.models.auction_bidding_configuration.AuctionBiddingConfiguration(
                    mode = 'OPEN', 
                    pre_bidding_allowed = True, 
                    max_bids_per_participants = 0, 
                    min_bid_price = 1.337, ),
                process_steps = empire_platform_api_public_client.models.auction_process_steps_absolute.AuctionProcessStepsAbsolute(
                    preliminary_spec_publish = '2022-01-04T00:00Z', 
                    returns_window_close = '2022-01-04T00:00Z', 
                    final_spec_publish = '2022-01-04T00:00Z', 
                    bidding_open = '2022-01-04T00:00Z', 
                    show_bids_for_open_auctions = '2022-01-04T00:00Z', 
                    bidding_close = '2022-01-04T00:00Z', 
                    provisional_results_publish = '2022-01-04T00:00Z', 
                    final_results_publish = '2022-01-04T00:00Z', ),
                offered_capacity_setup = 'PERCENT_100_ATC',
        )
        """

    def testDayAheadAuction(self):
        """Test DayAheadAuction"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
